# Base URL
ACCESS_TOKEN_URL = "https://accounts.tokopedia.com/token"
PLAYGROUND_SAT_BASE_URL = "https://b2b-playground.tokopedia.com/api"

# Path
PING_PATH = "/ping"
INQUIRY_PATH = "/v2/inquiry"
CHECKOUT_PATH = "/v2/order"
CHECK_STATUS_PATH = "/v2/order/{request_id}"
PRODUCT_LIST_PATH = "/v2/product-list"
ACCOUNT_PATH = "/v2/account"

SIGNATURE_HEADER_KEY = "signature"

SDK_NAME = "py_sat"
SDK_VERSION = "v1.0.0"
SDK_LABEL = f"{SDK_NAME}@{SDK_VERSION}"

DATE_TIME_FORMAT = "%a, %d %b %Y %H:%M:%S GMT"
